=============
Py-STAC Tools
=============


.. image:: https://img.shields.io/pypi/v/py-stac.svg
        :target: https://pypi.python.org/pypi/py-stac

.. image:: https://img.shields.io/travis/geobeyond/py-stac.svg
        :target: https://travis-ci.org/geobeyond/py-stac

.. image:: https://readthedocs.org/projects/py-stac/badge/?version=latest
        :target: https://py-stac.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python command line utilities for interacting with and creating STAC compliant files.


* Free software: Apache Software License 2.0
* Documentation: https://py-stac.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

